<?php
/**
 * Olam functions
 *
 * @package Olam
 */

define('INC_PATH', get_template_directory() . '/includes/');
require_once (INC_PATH . 'Walker_Comments.php');                  // Theme actions & user defined hooks
require_once (get_template_directory().'/admin/index.php');   // SMOF options
if ( file_exists( dirname( __FILE__ ) . '/admin/cmb/init.php' ) ) {
  require_once dirname( __FILE__ ) . '/admin/cmb/init.php';
} 


/* -- Custom Thumbnail sizes -- */
// Enabling product gallery features (zoom, swipe, lightbox) in woocommerce 3.0.0 (here enabling lightbox)
add_theme_support( 'wc-product-gallery-lightbox' );


if (function_exists('add_theme_support')) {
  add_theme_support('post-thumbnails');
  add_image_size('olam-product-thumb', 870, 9999, false);
  add_image_size('olam-product-thumb-small', 170, 170, true);
  add_image_size('olam-preview-image', 1180, 999, false);
  add_theme_support( 'custom-header' );
  add_theme_support( 'custom-background');
  add_theme_support( "title-tag" );
  add_theme_support( 'automatic-feed-links');
}

add_action( 'cmb2_admin_init', 'olam_register_download_metafields' );

/**
 * Olam Theme Functions - Register meta fields.
 * Registering meta fields to download post type.
**/

function olam_register_download_metafields() {
  $prefix = 'olam';
  /**
   * Sample metabox to demonstrate each field type included
   */
  $cmb_demo = new_cmb2_box( array(
    'id'            => $prefix . 'metabox',
    'title'         => esc_html__( 'Download Options', 'olam' ),
    'object_types'  => array( 'download')
    ) );

  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Preview URL', 'olam' ),
    'desc'       => esc_html__( 'The URL for the Live Preview button that shows on single download page under featured image / preview media', 'olam' ),
    'id'         => 'preview_url',
    'type'       => 'text',
    ));
  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Subheading', 'olam' ),
    'desc'       => esc_html__( 'Subheading for the item displayed under title', 'olam' ),
    'id'         => 'subheading',
    'type'       => 'text',

    ) );
  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Downloads Thumbnail', 'olam' ),
    'desc'       => esc_html__( 'Alternate thumbnail image instead of featured image to show in listing sections (slider thumb style)', 'olam' ),
    'id'         => 'download_item_thumbnail',
    'type'       => 'file',
    'options'    =>array(
      'url'     =>false,
      )
    ) );
  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Square Images', 'olam' ),
    'desc'       => esc_html__( 'Download item square image to show in different sections (shop, category, archives and shortcodes instead of featured image.)', 'olam' ),
    'id'         => 'download_item_square_img',
    'type'       => 'file',
    'options'    =>array(
      'url'     =>false,
      )
    ) );
  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Audio URL', 'olam' ),
    'desc'       => esc_html__( 'Upload the audio file preview file for the audio player', 'olam' ),
    'id'         => 'download_item_audio_id',
    'type'       => 'file',
    'options'    =>array(
      'url'     =>false,
      )
    )
  );
  // $cmb_demo->add_field( array(
  //   'name'       => esc_html__( 'Video URL', 'olam' ),
  //   'desc'       => esc_html__( 'Upload the video file to display in video player', 'olam' ),
  //   'id'         => 'download_item_video_id',
  //   'type'       => 'file',
  //   'options'    =>array(
  //     'url'     =>false,
  //     )
  //   )
  // );

  $cmb_demo->add_field( array(
    'name'       => esc_html__( 'Video URL', 'olam' ),
    'desc'       => esc_html__( 'Add the video url to display in video player preview (ideally Youtube, Vimeo or self hosted video URL)', 'olam' ),
    'id'         => 'download_item_video_id',
    'type'       => 'text',
    )
  );

}

if ( ! isset( $content_width ) ) $content_width = 1180;



/**
 * Olam Theme Functions - Add Editor Styles.
 * Adding styles to WP editor.
**/

function olam_add_editor_styles() {
  add_editor_style( 'css/editor-style.css' );
}
add_action( 'admin_init', 'olam_add_editor_styles' );

/**
 * Olam Theme Functions - Theme Setup.
 * Olam theme setup.
 * Loading text domain
**/

if( ! function_exists( 'olam_theme_setup' ) ){
  function olam_theme_setup(){
    load_theme_textdomain('olam', get_template_directory() . '/languages');
    add_theme_support( 'woocommerce' );
  }
}
add_action('after_setup_theme', 'olam_theme_setup');



/**
 * Olam Theme Functions - Registering Sidebars.
 * Registering the required sidebars.
**/

if( ! function_exists( 'olam_register_sidebars' ) ){
  function olam_register_sidebars(){
    if (function_exists('register_sidebar')) {

     register_sidebar(array(
      'name' => esc_html__('Single Download Sidebar','olam'),
      'id'   => 'olam-single-download',
      'description'   => esc_html__('Single Download Page Sidebar','olam'),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-cart"></i>',
      'after_title'   => '</div>'
      ));
     register_sidebar(
      array(
        'name' => esc_html__('Download Category Sidebar','olam'),
        'id'   => 'olam-download-category-sidebar',
        'description'   => esc_html__('Download Category Sidebar','olam'),
        'before_widget' => '',
        'after_widget'  => '',
        'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-folder"></i>',
        'after_title'   => '</div>'
        )
      );
     register_sidebar(
      array(
        'name' => esc_html__('Author Downloads Sidebar','olam'),
        'id'   => 'olam-author-sidebar',
        'description'   => esc_html__('Sidebar used in author downloads page','olam'),
        'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-folder"></i>',
        'after_title'   => '</div>',
        'before_widget' => '',
        'after_widget'  => '',
        )
      );
     register_sidebar(
      array(
        'name' => esc_html__('Blog Page Sidebar','olam'),
        'id'   => 'olam-blog-page-sidebar',
        'description'   => esc_html__('Blog Page Sidebar','olam'),
        'before_widget' => '',
        'after_widget'  => '',
        'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-folder"></i>',
        'after_title'   => '</div>'
        )
      );
     register_sidebar(
      array(
        'name' => esc_html__('Page Sidebar','olam'),
        'id'   => 'olam-page-sidebar',
        'description'   => esc_html__('Page Sidebar','olam'),
        'before_widget' => '',
        'after_widget'  => '',
        'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-folder"></i>',
        'after_title'   => '</div>'
        )
      );
     register_sidebar(
      array(
        'name' => esc_html__('Footer 1','olam'),
        'id'   => 'olam-footer-area-1',
        'description'   => esc_html__('Footer Area 1','olam'),
        'before_widget' => '',
        'after_widget'  => '',
        )
      );
     register_sidebar(
      array(
        'name' => esc_html__('Footer 2','olam'),
        'id'   => 'olam-footer-area-2',
        'description'   => esc_html__('Footer Area 2','olam'),
        'before_widget' => '',
        'after_widget'  => '',
        'before_title'  => '<h5>',
        'after_title'   => '</h5>'
        )
      );

     if ( class_exists( 'WooCommerce' ) ) {
     register_sidebar(array(
      'name' => esc_html__('Woocommerce Sidebar','olam'),
      'id'   => 'olam-woocommerce-sidebar',
      'description'   => esc_html__('Woocommerce Sidebar','olam'),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<div class="sidebar-title"><i class="demo-icons icon-cart"></i>',
      'after_title'   => '</div>'
      ));
      }
   }
 }
}

add_action( 'widgets_init', 'olam_register_sidebars');







/**
 * Olam Theme Functions - Register Menud.
 * Registering Menus.
**/

if( ! function_exists( 'olam_register_menus' ) ){
  function olam_register_menus() {
    register_nav_menus(
      array(
        'header-top-menu' => esc_html__('Header Menu','olam'),
        )
      );
  }
}
add_action('init', 'olam_register_menus');


/**
 * Olam Theme Functions - Register styles and scripts.
 * Loading theme scripts and styles.
**/

if( ! function_exists( 'olam_register_styles_scripts' ) ){
  function olam_register_styles_scripts(){
    $protocol  = is_ssl() ? 'https' : 'http';
    $loadedFonts=olam_load_googlefont_styles();
    wp_enqueue_style('normalize', get_template_directory_uri() . '/css/normalize.min.css',array(),'3.0.2');
    wp_enqueue_style('olam-bootstrap', get_template_directory_uri() . '/css/bootstrap.css',array(),'1.0');
    wp_enqueue_style('olam-style', get_template_directory_uri() . '/css/style.css',array(),'1.0');
    wp_enqueue_style('owl-carousel', get_template_directory_uri() .  '/css/owl.carousel.css',array(),'2.0');

    if ( class_exists( 'WooCommerce' ) ) {
    wp_enqueue_style('woocommerce-style', get_template_directory_uri() .  '/css/woocommerce-style.css');
    wp_enqueue_style('woocommerce', get_template_directory_uri() .  '/css/woocommerce.css');
    }
    wp_enqueue_style('olam-color', get_template_directory_uri().'/css/color.css.php',array(),'1.0');
    if( get_theme_mod('olam_dark_style') == 1 ) {
      wp_enqueue_style('dark-style', get_template_directory_uri() .  '/css/dark-style.css');
    }
    if(isset($loadedFonts) && (strlen($loadedFonts) >0 ) ) {
      wp_enqueue_style('olam-google-fonts',"{$protocol}://fonts.googleapis.com/css?family=".$loadedFonts);
    }
    wp_enqueue_script('modernizr', get_template_directory_uri().'/js/vendor/modernizr-2.8.3-respond-1.4.2.min.js',array('jquery'),'2.8.3');
    wp_enqueue_script('jquery-easypiechart', get_template_directory_uri().'/js/jquery.easypiechart.min.js',array('jquery'),'2.1.5', true);
    wp_enqueue_script('olam-bootstrap-js', get_template_directory_uri().'/js/bootstrap.min.js',array('jquery'),'1.0', true);
    wp_enqueue_script('sly', get_template_directory_uri().'/js/sly.min.js',array(),'1.5.1', true);
    wp_enqueue_script('owl-carousel', get_template_directory_uri().'/js/owl.carousel.min.js',array('jquery'),'2.0', true);
    //wp_enqueue_script('pretty-photo', get_template_directory_uri().'/js/jquery.prettyPhoto.js',array('jquery'),'3.1.6', true);
    wp_enqueue_script('appear', get_template_directory_uri().'/js/appear.js',array(),'1.0', true);
    wp_enqueue_script('easing', get_template_directory_uri().'/js/easing.js',array('jquery'),'1.3', true);
    wp_enqueue_script('jquery-parallax', get_template_directory_uri().'/js/jquery.parallax-1.1.3.js',array('jquery'),'1.1.3', true);
    if(isset($data['theme_retina']) && $data['theme_retina']==1){
      wp_enqueue_script('retina', get_template_directory_uri().'/js/retina.min.js',array(),'1.0',true);
    }
    wp_enqueue_script('olam-main', get_template_directory_uri().'/js/olam-main.js',array('jquery'),'1.0', true);

    if ( is_singular(array('post')) && comments_open() ){
      wp_enqueue_script('comment-reply');
    } 

    $ajax_url =(function_exists('edd_get_ajax_url'))?edd_get_ajax_url():admin_url( 'admin-ajax.php' );
    wp_localize_script(
      'olam-main',
      'olam_main_ajax',
      array(
        'ajaxurl' => $ajax_url,
        'nonce' => wp_create_nonce('olam_main'),
        'piecolor'=>get_theme_mod('olam_theme_pri_color'),
        )
      );

    // Body specs
    $bodyspecscolor=get_theme_mod('olam_bodycolor');
    $bodyspecsfont=get_theme_mod('olam_bodyfont');
    $bodyspecssize=get_theme_mod('olam_bodysize');
    $bodySpecs_color=(isset($bodyspecscolor))?$bodyspecscolor:null;
    $bodySpecs_font=(isset($bodyspecsfont))?$bodyspecsfont:null;
    $bodySpecs_size=(isset($bodyspecssize))?$bodyspecssize:null;
    $color = get_theme_mod( 'my-custom-color' ); //E.g. #FF0000

    $inner_page_heading = olam_get_page_option(get_the_ID(),"olam_disable_inner_page_heading");

        $custom_css = "
                body {
                  font-family : {$bodySpecs_font}, Arial, Helvetica;
                  color : {$bodySpecs_color};
                  font-size : {$bodySpecs_size}px;
                  }
        ";

        if($inner_page_heading){
          $custom_css.= "  .inner-page-heading{ display:none; }  ";
        }

        wp_add_inline_style( 'olam-color', $custom_css );
  }
}
add_action('wp_enqueue_scripts', 'olam_register_styles_scripts');


/**
 *  olam lightbox Function
 *  PRETTY PHOTO 
 *    Prettyphoto (not Fancybox) will continue to be registered but not enqueued, since woocommerse update 2.7
 */
if(class_exists('WooCommerce')){
  add_action( 'wp_enqueue_scripts', 'olam_lightbox' );
  function olam_lightbox() {
    global $woocommerce;
    $suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
    {
    wp_enqueue_script( 'prettyPhoto', esc_url( $woocommerce->plugin_url() ) . '/assets/js/prettyPhoto/jquery.prettyPhoto' . $suffix . '.js', array( 'jquery' ), $woocommerce->version, true );
    wp_enqueue_script( 'prettyPhoto-init', esc_url( $woocommerce->plugin_url() ) . '/assets/js/prettyPhoto/jquery.prettyPhoto.init' . $suffix . '.js', array( 'jquery' ), $woocommerce->version, true );
    wp_enqueue_style( 'woocommerce_prettyPhoto_css', esc_url( $woocommerce->plugin_url() ) . '/assets/css/prettyPhoto.css' );
    }
  }
}

/**
 * Olam Theme Function - Load admin styles
 * Loading admin styles.
**/

if( ! function_exists( 'olam_load_custom_wp_admin_style' ) ){
  function olam_load_custom_wp_admin_style() {
    wp_enqueue_style( 'olam-admin-styles', get_template_directory_uri() . '/css/admin-styles.css');
  }
}
add_action( 'admin_enqueue_scripts', 'olam_load_custom_wp_admin_style' );

/**
 * Olam Theme Function - Old IE Fixes
 * Fixes for old IE versions.
**/

if( ! function_exists( 'olam_old_ie_fixes' ) ){
  function olam_old_ie_fixes() {
    global $is_IE;
    if ( $is_IE ) {
      echo '<!--[if lt IE 9]>';
      echo '<script src="' . get_template_directory_uri() . '/assets/js/css3-mediaqueries.js" type="text/javascript"></script>';
      echo '<script src="' . get_template_directory_uri() . '/assets/js/html5shiv.js" type="text/javascript"></script>';
      echo '<script src="' . get_template_directory_uri() . '/assets/js/respond.min.js" type="text/javascript"></script>';
      echo '<script src="' . get_template_directory_uri() . '/assets/js/placeholders.min.js" type="text/javascript"></script>';
      echo '<![endif]-->';
    }
  }
}

add_action( 'wp_head', 'olam_old_ie_fixes' );


/**
 * Olam Function - Pagination.
 *
 * This function sets the pagination for post pages.
 */

if( ! function_exists( 'olam_pagination' ) ){
  function olam_pagination($pages = '', $range = 4, $ordinary=null) {

    // The Custom Pagination

    if(!isset($ordinary)){
      $showitems = ($range * 2) + 1;
      global $paged;
      if (empty($paged))
        $paged = 1;
      if ($pages == '') {
        global $wp_query;
        $pages = $wp_query->max_num_pages;
        if (!$pages) {
          $pages = 1;
        }
      }   
      if (1 != $pages) {
        echo "<div class=\"pagination\"><ul>";
        if ($paged > 2 && $paged > $range + 1 && $showitems < $pages)
          echo "<a href='" . get_pagenum_link(1) . "'>&laquo; ".esc_html__('First','olam')."</a>";
        if ($paged > 1 && $showitems < $pages)
          echo "<a href='" . get_pagenum_link($paged - 1) . "'>&lsaquo; ".esc_html__('Previous','olam')."</a>";
        echo "<li>".get_previous_posts_link('<i class="demo-icons icon-left"></i>')."</li>";
        for ($i = 1; $i <= $pages; $i++) {
          if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems )) {
            echo _($paged == $i) ? "<li class=\"active\"><a href='#'>" . $i . "</a></li>" : "<li><a href='" . get_pagenum_link($i) . "' >" . $i . "</a></li>";
          }
        }
        echo "<li>".get_next_posts_link('<i class="demo-icon icon-right"></i>')."</li>";
        if ($paged < $pages && $showitems < $pages)
          echo "<a href=\"" . get_pagenum_link($paged + 1) . "\">".esc_html__('Next','olam')." &rsaquo;</a>";
        if ($paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages)
          echo "<a href='" . get_pagenum_link($pages) . "'>".esc_html__('Last','olam')." &raquo;</a>";
        echo "</ul></div>";
      }}
    else{ // The default wp pagination.
      if( get_next_posts_link() || get_previous_posts_link() ) { 
        echo '<div class="pagination-centered">
        <ul class="pagination pagination-lg">
          <li>'.get_previous_posts_link('&laquo; '.esc_html__("Previous Entries","olam").'').'</li>
          <li>'.get_next_posts_link(''.esc_html__("Next Entries","olam").' &raquo;').'</li>
        </ul>
      </div>';
    }
  }
}
}


/**
 * Olam Function - ajax url.
 *
 * This function sets the ajaxurl.
 */

if( ! function_exists( 'olam_ajaxurl' ) ){
  function olam_ajaxurl() {
    ?>
    <script type="text/javascript">
      var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
    </script>
    <?php
  }
}
add_action('wp_head','olam_ajaxurl');

/**
 * Olam Function - Get Author Tags.
 *
 * This function gets the author posts tags.
 */

if( ! function_exists( 'olam_get_author_tags' ) ){
  function olam_get_author_tags($id) {
    $user_tags = array();
    $query = new WP_Query(array(
      'posts_per_page' => -1,
      'author' => $id,
      'post_type'=>'download'
      ) );
    while ($query->have_posts()) {
      $query->the_post();
      $tags = wp_get_object_terms( get_the_ID(), 'download_tag');
      foreach ($tags as $key => $val) {
        if ($val->term_id > 0) {
          if (!array_key_exists($val->term_id, $user_tags)) {
            $user_tags[$val->term_id] = $val;
          }
        }
      }
    }
    return $user_tags;
  }
}

/**
 * Olam Function - Get page options.
 *
 * This function gets the page meta options.
 */

if( ! function_exists( 'olam_get_page_option' ) ){
  function olam_get_page_option($pageID,$pageOption){

    $allOptions= get_post_meta($pageID,'fw_options');
    $pageOptionData=(isset($allOptions[0][$pageOption]))?$allOptions[0][$pageOption]:false;
    return $pageOptionData;

  }
}

/**
 * Olam Function - EDD Sale Count.
 *
 * This function gets the edd sale count.
 */

if( ! function_exists( 'olam_get_edd_sale_count' ) ){
  function olam_get_edd_sale_count($postID){
   return get_post_meta( $postID, '_edd_download_sales', true ); 
 }
}

/**
 * Olam Function -  Get Comments.
 *
 * This function gets downloads comment count.
 */

if( ! function_exists( 'olam_get_comment_count' ) ){
  function olam_get_comment_count($postID){
    $itemComments=get_comments(
      array (
        // post ID
        'post_id' => $postID,
        // return just the total number
        'count'   => TRUE
        )
      );
    return $itemComments;
  }
}

/**
 * Olam Function - Authorization init.
 *
 * Initializing the authorisation.
 */

if( ! function_exists( 'olam_authorisation_init' ) ){
  function olam_authorisation_init(){
    if (function_exists('edd_get_option')) { 
      $loginRedirectPageID=edd_get_option( 'login_redirect_page', '' );
      $loginRedirect=get_permalink( $loginRedirectPageID ); 
    } else {
      $loginRedirect=home_url();
    }    
    wp_enqueue_script('olam-register-login', get_template_directory_uri().'/js/olam-register-login.js', array('jquery'));
    wp_localize_script( 'olam-register-login', 'ajax_auth_object', array(
      'ajaxurl'     => admin_url( 'admin-ajax.php' ),
      'redirecturl'   => isset($loginRedirect) ? $loginRedirect : home_url(),
      'loadingmessage'  => esc_html__('Sending user info, please wait...','olam')
      ));
    add_action( 'wp_ajax_olam_ajaxlogin', 'olam_ajaxlogin' );
    add_action( 'wp_ajax_nopriv_olam_ajaxlogin', 'olam_ajaxlogin' );
    add_action( 'wp_ajax_nopriv_olam_ajaxregister','olam_ajax_register' );
    add_action( 'wp_ajax_olam_ajaxregister', 'olam_ajax_register' );
  }
}
add_action('init', 'olam_authorisation_init');

/**
 * Olam Function - Ajax Login.
 *
 * Ajax popup login actions.
 */

if( ! function_exists( 'olam_ajaxlogin' ) ){
  function olam_ajaxlogin(){

    // First check the nonce, if it fails the function will break
    check_ajax_referer( 'ajax-login-nonce', 'security' );

    // Nonce is checked, get the POST data and sign user on
    // Call auth_user_login
    olam_auth_user_login($_POST['username'], $_POST['password'], 'Login'); 
    
    die();
  }
}

/**
 * Olam Function - Ajax Register.
 *
 * Ajax popup register actions.
 */

if (!function_exists('olam_ajax_register')) {
    function olam_ajax_register()
    {

        global $options;
        $options = get_option('olam_register_login');

        // First check the nonce, if it fails the function will break
        check_ajax_referer('ajax-register-nonce', 'security');

        // Nonce is checked, get the POST data and sign user on
        $info = array();
        $info['user_nicename'] = $info['nickname'] = $info['display_name'] = $info['first_name'] = $info['user_login'] = sanitize_user($_POST['username']);
        $info['user_pass'] = sanitize_text_field($_POST['password']);
        $info['user_email'] = sanitize_email($_POST['email']);
        $info['phone_number'] = sanitize_text_field($_POST['phone_number']); // Add phone number field data

        // Register the user

        if (!is_email($info['user_email'])) {
            echo json_encode(array('loggedin' => false, 'message' => esc_html__("Please enter a valid email address", "olam")));
            die();
        }
        if (sanitize_text_field($_POST['password2']) != $info['user_pass']) {
            echo json_encode(array('loggedin' => false, 'message' => esc_html__("Please enter the same password in both fields", "olam")));
            die();
        }
        if (!isset($info['user_pass']) || !(strlen($info['user_pass']) > 0)) {
            echo json_encode(array('loggedin' => false, 'message' => esc_html__("Password fields cannot be blank", "olam")));
            die();
        }

        $user_register = wp_insert_user($info);
        if (is_wp_error($user_register)) {
            $error = $user_register->get_error_codes();

            if (in_array('empty_user_login', $error))
                echo json_encode(array('loggedin' => false, 'message' => $user_register->get_error_message('empty_user_login')));
            elseif (in_array('existing_user_login', $error))
                echo json_encode(array('loggedin' => false, 'message' => esc_html__('This username is already registered.', 'olam')));
            elseif (in_array('existing_user_email', $error))
                echo json_encode(array('loggedin' => false, 'message' => esc_html__('This email address is already registered.', 'olam')));
        } else {
            // Save phone number field data to usermeta
            update_user_meta($user_register, 'phone_number', $info['phone_number']);

            olam_auth_user_login($info['nickname'], $info['user_pass'], 'Registration');
        }

        die();
    }
}

/**
 * Olam Function - Auth user login.
 *
 * Authenticating the popup login user.
 */

if( ! function_exists( 'olam_auth_user_login' ) ){
  function olam_auth_user_login($user_login, $password, $login)
  { 
    $info = array();
    $info['user_login'] = $user_login;
    $info['user_password'] = $password;
    $info['remember'] = true;
    
    add_action( 'set_logged_in_cookie', 'olam_loggedin_cookie' );
    function olam_loggedin_cookie( $logged_in_cookie ){
        $_COOKIE[LOGGED_IN_COOKIE] = $logged_in_cookie;
    }

    $user_signon = wp_signon( $info, is_ssl() ? true : false);
    if ( is_wp_error($user_signon) ){
      echo json_encode(array('loggedin'=>false, 'message'=>esc_html__('Wrong username or password.','olam')));
    } else {
      global $current_user;
      wp_set_current_user($user_signon->ID); 
      if($login=="Login"){
       echo json_encode(array('loggedin'=>true, 'message'=>esc_html__('Login successful, redirecting...','olam')));
     }
     else{
       echo json_encode(array('loggedin'=>true, 'message'=>esc_html__('Registration successful, redirecting...','olam')));
     }
     
   }
   
   die();
 }
}

/**
 * Olam Function - Printing the current user name.
 *
 * Displays the currently logged in user name.
 */

if( ! function_exists( 'olam_print_current_user_name' ) ){
  function olam_print_current_user_name(){
    $current_user = wp_get_current_user();
    echo esc_html($current_user->user_login);
  }
}
add_action( 'wp_ajax_olam_main_ajax',  'olam_main_ajax' );
add_action( 'wp_ajax_nopriv_olam_main_ajax','olam_main_ajax');

/**
 * Olam Function - Main Ajax,mini cart.
 *
 * Mini cart main ajax action.
 */

if( ! function_exists( 'olam_main_ajax' ) ){
  function olam_main_ajax(){
    if(isset($_GET['cart_count']) && ($_GET['cart_count']==1) ){
      echo edd_get_cart_quantity();
    }
    else{
      olam_print_mini_cart();
    }
    die();
  }
}

/**
 * Olam Function - Remove Item Url
 * Returns the URL to remove an item from the cart (Used in Mini cart)
 *
 * parameters   => int    - $cart_key   - Cart item key
 *                 int    - $cart_key_id- Cart item Post ID
 * return value => string - $remove_url - URL to remove the cart item
 */

if( ! function_exists( 'olam_remove_item_url' ) ){
  function olam_remove_item_url( $cart_key, $cart_key_id ) {
    if ( defined( 'DOING_AJAX' ) ) {
      $current_page = edd_get_current_page_url();
    } else {
      $current_page = edd_get_current_page_url();
    }

    $remove_url = edd_add_cache_busting( add_query_arg( array( 'cart_item' => $cart_key, 'edd_action' => 'remove' ), $current_page ) );
    return apply_filters( 'edd_remove_item_url', $remove_url );
  }
}


/**
 * Olam Function - Print Mini Cart
 *
 * Displays the header minicart widget
 */


// Check if Easy Digital Downloads exists
if( ! function_exists( 'olam_check_edd_exists' ) ) {
    function olam_check_edd_exists() {
        return class_exists('Easy_Digital_Downloads');
    }
}

// Function to print mini cart
if( ! function_exists( 'olam_print_mini_cart' ) ){
    function olam_print_mini_cart(){ 
        if(!olam_check_edd_exists()){
            return; 
        }
        ?>
        <div class="cart-widget">
            <span class="cart-btn">
                <i class="demo-icon icon-cart"></i>
                <span> <?php echo edd_get_cart_quantity();?> <?php esc_html_e("Items","olam"); ?></span>
            </span>
            <!-- Cart widget -->
            <div class="dd-cart">
                <div class="inner-scroll">
                    <ul class="cart_list product_list_widget ">
                        <?php $cartContents = edd_get_cart_contents();                    
                        if($cartContents) {
                            foreach ($cartContents as $cartContentsKey => $cartContentsValue) { ?>
                                <li>
                                    <a href="<?php echo esc_url( wp_nonce_url( edd_remove_item_url( $cartContentsKey ), 'edd-remove-from-cart-' . $cartContentsKey, 'edd_remove_from_cart_nonce' ) ); ?>" class="remove-item edd_cart_remove_item_btn" title="<?php esc_attr_e('Remove this item','olam');?>">x</a>                                                    
                                    <a href="<?php echo get_permalink($cartContentsValue['id']); ?>">
                                        <?php
                                        $featImage = null;
                                        $realfeatImageData = wp_get_attachment_image_src(get_post_thumbnail_id($cartContentsValue['id']), 'olam-product-thumb-small');
                                        $realfeatImage = $realfeatImageData ? $realfeatImageData[0] : null;

                                        $theDownloadImage = get_post_meta($cartContentsValue['id'], 'download_item_thumbnail_id'); 

                                        if (is_array($theDownloadImage) && count($theDownloadImage) > 0) {
                                            $thumbID = $theDownloadImage[0];
                                            $featImageData = wp_get_attachment_image_src($thumbID, 'olam-product-thumb-small');
                                            $featImage = $featImageData ? $featImageData[0] : null;
                                        } else {
                                            $thumbID = get_post_thumbnail_id($cartContentsValue['id']);
                                            $featImageData = wp_get_attachment_image_src($thumbID, 'olam-product-thumb-small');
                                            $featImage = $featImageData ? $featImageData[0] : null;
                                        }           
                                        ?>
                                        <?php if(isset($featImage) && strlen($featImage) > 0) { 
                                            $alt = get_post_meta($thumbID, '_wp_attachment_image_alt', true);
                                            ?> 
                                            <img src="<?php echo esc_url($featImage);  ?>" class="attachment-shop_thumbnail wp-post-image" alt="<?php echo esc_html(get_the_title($cartContentsValue['id'])); ?>">
                                        <?php } elseif (isset($realfeatImage)) { ?>
                                            <img src="<?php echo esc_url($realfeatImage); ?>" alt="<?php echo esc_html(get_the_title($cartContentsValue['id'])); ?>">
                                        <?php } else { ?>
                                            <img src="<?php echo esc_url(get_template_directory_uri()); ?>/img/product-thumb-small.jpg" alt="cart item">
                                        <?php } ?>  
                                    </a>

                                    <span class="cart-list-text">
                                        <span class="cart-list-title"><?php echo esc_html(get_the_title($cartContentsValue['id'])); ?></span>
                                        <span class="quantity">
                                            <span class="cart-quantity"><?php echo esc_html($cartContentsValue['quantity']); ?> x </span>
                                            <span class="amount"><?php 
                                            if(count($cartContentsValue['options']) > 0) { 
                                                //echo edd_cart_item_price( $cartContentsValue['id'], $cartContentsValue['options']);
                                                edd_price($cartContentsValue['id']); 
                                            } else {
                                                edd_price($cartContentsValue['id']); 
                                            } ?></span>
                                        </span>
                                        <span class="clearfix"></span>
                                    </li>
                                <?php } ?>
                            </ul><!-- end product list -->

                            <!-- subtotal and tax -->
                            <?php $hidecarttax = get_theme_mod('olam_hide_header_cart_tax');
                            if ($hidecarttax == 0) { ?>
                            <div class="header-cart-subtotal-tax">
                                <?php if( edd_use_taxes() && ! edd_prices_include_tax() ) : ?>
                                    <div class="header-cart-subtotal"<?php if ( ! edd_is_cart_taxed() ) echo ' style="display:none;"'; ?>>
                                        <?php _e( 'Subtotal', 'olam' ); ?>:&nbsp;<span class="edd_cart_subtotal_amount"><?php echo edd_cart_subtotal(); ?></span>
                                    </div>
                                <?php endif; ?>

                                <?php if( edd_use_taxes() ) : ?>
                                    <div class="header-cart-tax"<?php if( ! edd_is_cart_taxed() ) echo ' style="display:none;"'; ?>>
                                        <?php _e( 'Estimated Tax', 'olam' ); ?>:&nbsp;<span class="edd_cart_tax_amount"><?php echo esc_html( edd_cart_tax() ); ?></span>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <?php } ?><!-- end subtotal and tax -->

                            <p class="total"><strong><?php esc_html_e("Total:","olam"); ?></strong> <span class="amount"><?php edd_cart_total(); ?></span></p>
                            <p class="buttons">
                                <a href="<?php echo edd_get_checkout_uri(); ?>"><?php esc_html_e("Checkout","olam"); ?></a>
                            </p>
                            <?php } else { ?>
                            <li>
                                <div class="empty-cart text-center">
                                    <div class="cart-icon"><i class="demo-icon icon-cart"></i></div>
                                    <span class="edd_empty_cart"><?php esc_html_e("Your cart is empty!","olam"); ?></span>
                                </div>
                            </li>
                        </ul>
                        <?php } ?>
                    </div>
                </div>                        
            </div>
        <?php }
    }




/**
 * Olam Function - Is Default Editor Only.
 *
 * Check whether the page is using the default WordPress editor only
 * not the unyson shortcodes or pagebuilder .
 */

if( ! function_exists( 'olam_is_default_editor_only' ) ){
  function olam_is_default_editor_only(){
    $pageMeta=get_post_meta(get_the_ID(),'fw_options');
    if(isset($pageMeta[0]['page-builder']['builder_active'])){
      if($pageMeta[0]['page-builder']['builder_active']==1){
        return false;
      }
    }
    return true;
  }
}

/**
 * Olam Function - Get Avatar Url.
 *
 * Getting the avatar url.
 */

if( ! function_exists( 'olam_get_avatar_url' ) ){
  function olam_get_avatar_url($get_avatar){
    preg_match("/src='(.*?)'/i", $get_avatar, $matches);
    return $matches[1];
  }
}
/**
 * Olam Function - Build author url.
 *
 * Returns the author downloads page url for author link
 * displayed the downloads lists pages.
 */

if( ! function_exists( 'olam_build_author_url' ) ){
  function olam_build_author_url($author){
    return add_query_arg( 'author_downloads', 'true', get_author_posts_url($author) );
  }
}




/**
*Create the profile page URL, check if single author or FES active then vendor url
*/
function olam_edd_fes_author_url( $author = null, $user_id = null ) {
  // get vendor meta ID
  $user_id = get_the_author_meta( 'ID' );
  // get vendor id
  $vendor_id = get_the_author_meta( 'ID' , $user_id );

  if ( ! $author ) {
  $author = wp_get_current_user();
  } else {
  $author = new WP_User( $author );
  }
  if ( ! class_exists( 'EDD_Front_End_Submissions' ) ) {
    $full_url = get_author_posts_url( $author->ID, $author->user_nicename ).'?author_downloads=true';
  return $full_url;
  }
  return EDD_FES()->vendors->get_vendor_store_url( $vendor_id );
}




/* Adding Image Upload and other Fields in author page */
add_action( 'show_user_profile', 'olam_extra_profile_fields' );
add_action( 'edit_user_profile', 'olam_extra_profile_fields' );

/**
 * Olam Function - Extra Profile Fields.
 *
 * Adding extra fields to author profile,displayed in author archive for downloads.
 */

if( ! function_exists( 'olam_extra_profile_fields' ) ){
  function olam_extra_profile_fields( $user ) 
  { 
    ?>

    <h3><?php esc_html_e("Author Download Page Fields","olam"); ?></h3>
    <table class="form-table fh-profile-upload-options">
      <tr>
        <th>
          <label for="author_page_title"><?php esc_html_e("Author Downloads Page Title","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_page_title" id="author_page_title" value="<?php echo esc_attr( get_the_author_meta( 'author_page_title', $user->ID ) ); ?>" class="regular-text" />      
          <span class="description"><?php esc_html_e("Please input Author Page Title.","olam"); ?></span>
        </td>
      </tr>
      <tr>
        <th>
          <label for="author_page_subtitle"><?php esc_html_e("Author Downloads Page Subtitle","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_page_subtitle" id="author_page_subtitle" value="<?php echo esc_attr( get_the_author_meta( 'author_page_subtitle', $user->ID ) ); ?>" class="regular-text" />      
          <span class="description"><?php esc_html_e("Please input Author Subtitle.","olam"); ?></span>
        </td>
      </tr>
    </table>
    <table class="form-table fh-profile-upload-options">
      <tr>
        <th>
          <label for="authorbanner"><?php esc_html_e("Author Profile Picture","olam"); ?></label>
        </th>
        <td>
          <img class="user-preview-image" src="<?php echo esc_attr( get_the_author_meta( 'authorbanner', $user->ID ) ); ?>">
          <input type="text" name="authorbanner" id="authorbanner" value="<?php echo esc_attr( get_the_author_meta( 'authorbanner', $user->ID ) ); ?>" class="regular-text" />
          <input type='button' class="button-primary" value="<?php esc_html_e("Upload Image","olam"); ?>" id="authorbannerUploadimage"/><br />
          <span class="description"><?php esc_html_e("Please upload your author profile picture(square).","olam"); ?></span>
        </td>
      </tr>
    </table>
    <h3><?php esc_html_e("Social Media","olam"); ?></h3>
    <table class="form-table fh-profile-upload-options">
      <tr>
        <th>
          <label for="author_fb_url"><?php esc_html_e("Facebook Url","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_fb_url" id="author_fb_url" value="<?php echo esc_attr( get_the_author_meta( 'author_fb_url', $user->ID ) ); ?>" class="regular-text" />      
          <span class="description"><?php esc_html_e("Please input facebook url.","olam"); ?></span>
        </td>
      </tr>
      <tr>
        <th>
          <label for="author_youtube_url"><?php esc_html_e("Youtube Url","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_youtube_url" id="author_youtube_url" value="<?php echo esc_attr( get_the_author_meta( 'author_youtube_url', $user->ID ) ); ?>" class="regular-text" />      
          <span class="description"><?php esc_html_e("Please input youtube url.","olam"); ?></span>
        </td>
      </tr>
      <tr>
        <th>
          <label for="author_twitter_url"><?php esc_html_e("Twitter Url","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_twitter_url" id="author_twitter_url" value="<?php echo esc_attr( get_the_author_meta( 'author_twitter_url', $user->ID ) ); ?>" class="regular-text" />
          <span class="description"><?php esc_html_e("Please input twitter url.","olam"); ?></span>
        </td>
      </tr>
      <tr>
        <th>
          <label for="author_linkedin_url"><?php esc_html_e("LinkedIn Url","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_linkedin_url" id="author_linkedin_url" value="<?php echo esc_attr( get_the_author_meta( 'author_linkedin_url', $user->ID ) ); ?>" class="regular-text" />    
          <span class="description"><?php esc_html_e("Please input linked in url.","olam"); ?></span>
        </td>
      </tr>
      <tr>
        <th>
          <label for="author_instagram_url"><?php esc_html_e("Instagram Url","olam"); ?></label>
        </th>
        <td>
          <input type="text" name="author_instagram_url" id="author_instagram_url" value="<?php echo esc_attr( get_the_author_meta( 'author_instagram_url', $user->ID ) ); ?>" class="regular-text" />
          <span class="description"><?php esc_html_e("Please input Instagram url.","olam"); ?></span>
        </td>
      </tr>
    </table>
    <script type="text/javascript">
      (function( $ ) {

        $( 'input#authorbannerUploadimage' ).on('click', function() {
          tb_show('', 'media-upload.php?type=image&TB_iframe=true');

          window.send_to_editor = function( html ) 
          {
            imgurl = $( 'img', html ).attr( 'src' );
            $( '#authorbanner' ).val(imgurl);
            tb_remove();
          }

          return false;
        });
      })(jQuery);
    </script>

    <?php 
  }
}

add_action( 'personal_options_update', 'olam_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'olam_save_extra_profile_fields' );

/**
 * Olam Function - Save Extra Profile Fields.
 *
 * Saving  extra fields in author profile page in admin.
 */

if( ! function_exists( 'olam_save_extra_profile_fields' ) ){
  function olam_save_extra_profile_fields( $user_id ) {

    if ( !current_user_can( 'edit_user', $user_id ) )
    {
      return false;
    }

    update_user_meta( $user_id, 'authorbanner', wp_kses_post($_POST[ 'authorbanner' ]) );
    update_user_meta( $user_id, 'author_fb_url', wp_kses_post($_POST[ 'author_fb_url' ]) );
    update_user_meta( $user_id, 'author_youtube_url', wp_kses_post($_POST[ 'author_youtube_url' ] ));
    update_user_meta( $user_id, 'author_linkedin_url', wp_kses_post($_POST[ 'author_linkedin_url' ]) );
    update_user_meta( $user_id, 'author_twitter_url', wp_kses_post($_POST[ 'author_twitter_url' ]) );
    //update_user_meta( $user_id, 'author_gplus_url', wp_kses_post($_POST[ 'author_gplus_url' ]) );
    update_user_meta( $user_id, 'author_instagram_url', wp_kses_post($_POST[ 'author_instagram_url' ]) );
    update_user_meta( $user_id, 'author_page_title', wp_kses_post($_POST[ 'author_page_title' ]) );
    update_user_meta( $user_id, 'author_page_subtitle', wp_kses_post($_POST[ 'author_page_subtitle' ]) );
  }
}

/**
 * Olam Function - Enqueue Admin scripts.
 *
 * Enqueing admin page scripts.
 */

if( ! function_exists( 'olam_enqueue_admin' ) ){
  function olam_enqueue_admin()
  {
    wp_enqueue_script( 'thickbox' );
    wp_enqueue_style('thickbox');
    wp_enqueue_script('media-upload');
  }
}
add_action( 'admin_enqueue_scripts', 'olam_enqueue_admin' );

/**
 * Olam Function - Load google font styles.
 *
 * Returning user selected google fonts .
 */

if( ! function_exists( 'olam_load_googlefont_styles' ) ){
  function olam_load_googlefont_styles(){
    $olambodyfont=get_theme_mod('olam_bodyfont');
    $olamheadfont=get_theme_mod('olam_headfont');
    $bodyFont=(isset($olambodyfont))?$olambodyfont:null;
    $headFont=(isset($olamheadfont))?$olamheadfont:null;
    $bodyFont=olam_check_system_fonts($bodyFont);
    $headFont=olam_check_system_fonts($headFont);
    $fontArray=array($bodyFont,$headFont);
    $fontArray=array_filter(array_unique($fontArray));
    if($needleKey=array_search('none', $fontArray)){
      unset($fontArray[$needleKey]);
    }
    $finalFontArray=array();
    foreach ($fontArray as $fontKey => $fontValue) {
      $finalFontArray[]=olam_font_weights($fontValue);     
    }
    $implodedGoogleFonts=implode("|", $finalFontArray);
    return $implodedGoogleFonts;

  }
}

/**
 * Olam Function - Font weights.
 *
 * Loading Font weights for predefined fonts.
 */

if( ! function_exists( 'olam_font_weights' ) ){
  function olam_font_weights($tempFont){

   $presetFonts=array(
    "Open+Sans"=>array(300,400,600,700),
    "Roboto"  =>array(100,300,400,500,700),
    "Roboto Condensed" =>array(300,400,700),
    "Roboto Slab" => array(100,300,400,700),
    "Lato"    => array(100,300,400,700),
    "Oswald"  => array(300,400,700),
    "Raleway"   => array(100,300,400,500,700),
    "Droid Sans"=> array(400,700),
    "Ubuntu"  =>   array(300,400,500,700),
    "Montserrat" => array(400,700)
    );

   if(array_key_exists($tempFont, $presetFonts)){
     $tempFont=str_replace(' ','+', $tempFont);
     if(is_array($presetFonts[$tempFont])){
       $theFinalFont=$tempFont.":".implode(",", $presetFonts[$tempFont]);
     }
   }
   else{
    $gFile = INC_PATH . '/googlefonts.php';
    $gFonts= include $gFile;
    if(array_key_exists($tempFont, $gFonts)){
      $tempFsize=array();
      foreach ($gFonts[$tempFont]['variants'] as $tempFkey => $tempFvalue) {
        $tempFsize[]=$tempFvalue['id'];
      }
      $finalSizeArray=array_map("olam_array_filter",$tempFsize);
      $finalSize=array_filter($finalSizeArray);
      $tempFont=str_replace(' ','+', $tempFont);
      if(is_array($finalSize)){
        $theFinalFont=$tempFont.":".implode(",", $finalSize);
      }
    }
    else{
      $tempFont=str_replace(' ','+', $tempFont); 
      $theFinalFont=$tempFont;
    }

  }
  return $theFinalFont;

}
}

/**
 * Olam Function - Array Filter.
 *
 * Custom array filter for google font size .
 */

if( ! function_exists( 'olam_array_filter' ) ){
  function olam_array_filter($item){

    $array=array("300","400","700");
    if(in_array($item, $array)){
      return $item;
    }

  }
}
/**
 * Olam Function - Check System Fonts.
 *
 * Checking if a particular fonts is a system font .
 */

if( ! function_exists( 'olam_check_system_fonts' ) ){
  function olam_check_system_fonts($font){

    $systemFonts=array(
      "arial",
      "verdana",
      "trebuchet",
      "trebuchet ms",
      "georgia",
      "times",
      "tahoma",
      "helvetica"
      );
    if(!in_array($font, $systemFonts)){
      return $font;
    }
    return null;
  }
}


/**
 * Olam Function - Get RevSliders
 * This function gets the saved revolution sliders.
 */

if( ! function_exists( 'olam_get_rev_sliders' ) ){
  function olam_get_rev_sliders (){
    if(!class_exists('RevSlider')){
     return false;
   }
   else{

     $theslider     = new RevSlider();
     $arrSliders = $theslider->getArrSliders();
     $arrA     = array();
     $arrT     = array();
     foreach($arrSliders as $slider){
      $arrA[]     = $slider->getAlias();
      $arrT[]     = $slider->getTitle();
    }
    if($arrA && $arrT){
      $result = array_combine($arrA, $arrT);
    }
    else
    {
      $result = false;
    }
    return $result;
  }
}
}
/**
 * Olam Function - Get Current page url.
 *
 * Returning current page url .
 */

if( ! function_exists( 'olam_get_current_page_url' ) ){
  function olam_get_current_page_url(){

    global $wp;
    $current_url = home_url( add_query_arg( array(), $wp->request ) );

    return $current_url;

  }
}
add_action('admin_init','olam_checkRetinaDisplay');


/**
 * Olam Function - Check Retina Display.
 * This function check whether the retina display is enabled in the theme settings.
 */

if( ! function_exists( 'olam_checkRetinaDisplay' ) ){
  function olam_checkRetinaDisplay(){

    $olamOptions=of_get_options();
    if(isset($olamOptions['theme_retina']) && $olamOptions['theme_retina']==1){
      add_filter( 'wp_generate_attachment_metadata', 'olam_retinaAttachmentMeta', 10, 2 );
      add_filter( 'delete_attachment', 'olam_deleteRetinaImages' );
    }

  }
}

/**
 * Olam function - Retina images.
 *
 * This function is attached to the 'wp_generate_attachment_metadata' filter hook.
 */

if( ! function_exists( 'olam_retinaAttachmentMeta' ) ){
  function olam_retinaAttachmentMeta( $metadata, $attachment_id ) {
    foreach ( $metadata as $key => $value ) {
      if ( is_array( $value ) ) {
        foreach ( $value as $image => $attr ) {
          if ( is_array( $attr ) && (count($attr)>0) ){
            olam_createRetinaImages( get_attached_file( $attachment_id ), $attr['width'], $attr['height'], true );
          }
        }
      }
    }
    return $metadata;
  }
}

/**
 * Olam Function - Create retina-ready images.
 *
 * Referenced via olam_retinaAttachmentMeta().
 */

if( ! function_exists( 'olam_createRetinaImages' ) ){
  function olam_createRetinaImages( $file, $width, $height, $crop = false ) {
    if ( $width || $height ) {
      $resized_file = wp_get_image_editor( $file );
      if ( ! is_wp_error( $resized_file ) ) {
        $filename = $resized_file->generate_filename( $width . 'x' . $height . '@2x' );
        $resized_file->resize( $width * 2, $height * 2, $crop );
        $resized_file->save( $filename );
        $info = $resized_file->get_size();
        return array(
          'file' => wp_basename( $filename ),
          'width' => $info['width'],
          'height' => $info['height'],
          );
      }
    }
    return false;
  }
}

/**
 * Olam Function - Delete retina-ready images.
 *
 * This function is attached to the 'delete_attachment' filter hook.
 */

if( ! function_exists( 'olam_deleteRetinaImages' ) ){
  function olam_deleteRetinaImages( $attachment_id ) {

    $meta = wp_get_attachment_metadata( $attachment_id );
    $upload_dir = wp_upload_dir();
    $path = (isset($meta['file']))?pathinfo( $meta['file'] ):null;
    if((is_array($meta)) && count($meta)>0){
      foreach ( $meta as $key => $value ) {
        if ( 'sizes' === $key ) {
          foreach ( $value as $sizes => $size ) {
            $original_filename = $upload_dir['basedir'] . '/' . $path['dirname'] . '/' . $size['file'];
            $retina_filename = substr_replace( $original_filename, '@2x.', strrpos( $original_filename, '.' ), strlen( '.' ) );
            if ( file_exists( $retina_filename ) )
              unlink( $retina_filename );
          }
        }
      }
    }
  }
}

/**
 * Olam Function - Check if added to cart.
 *
 * Check if an item exists or is added to cart already.
 */

if( ! function_exists( 'olam_check_if_added_to_cart' ) ){
  function olam_check_if_added_to_cart( $itemID ) {

    $cartItems=edd_get_cart_contents();
    $cartIDs=olam_get_cart_IDs($cartItems);
    if(in_array($itemID, $cartIDs)){
      return true;
    }
    return false;
  }
}

/**
 * Olam Function - Get cart item ids.
 *
 * Getting the cart item ids.
 */

if( ! function_exists( 'olam_get_cart_IDs' ) ){
  function olam_get_cart_IDs( $cartItems ) {

    $cartIDs=array();
    if(is_array($cartItems)){
      foreach ($cartItems as $cartItemkey => $cartItemvalue) {
        $cartIDs[]=$cartItemvalue['id'];
      }
    }
    return $cartIDs;
  }
}



// =========== TGM_Plugin =============

  /**
   * This file represents an example of the code that themes would use to register
   * the required plugins.
   *
   * It is expected that theme authors would copy and paste this code into their
   * functions.php file, and amend to suit.
   *
   * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
   *
   * @package    TGM-Plugin-Activation
   * @subpackage Example
   * @version    2.6.1
   * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
   * @copyright  Copyright (c) 2011, Thomas Griffin
   * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
   * @link       https://github.com/TGMPA/TGM-Plugin-Activation
   */

  /**
   * Include the TGM_Plugin_Activation class.
   *
   * Depending on your implementation, you may want to change the include call:
   *
   * Parent Theme:
   * require_once get_template_directory() . '/path/to/class-tgm-plugin-activation.php';
   *
   * Child Theme:
   * require_once get_stylesheet_directory() . '/path/to/class-tgm-plugin-activation.php';
   *
   * Plugin:
   * require_once dirname( __FILE__ ) . '/path/to/class-tgm-plugin-activation.php'; // change "dirname( __FILE__ )" to "get_template_directory()" for Themeforest standards.
   */
// Ensure the function to check active plugins is available
if ( ! function_exists( 'is_plugin_active' ) ) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

require_once get_template_directory() . '/admin/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'olam_register_required_plugins' );

function olam_register_required_plugins() {
    $plugins = array(
        // Always required plugins
        array(
            'name'               => esc_html__( 'Olam EDD FES', 'olam' ),
            'slug'               => 'olam-edd-fes-meta-fields',
            'source'             => esc_url( get_template_directory_uri() . '/admin/plugins/olam-edd-fes-meta-fields.zip' ),
            'required'           => false,
            'version'            => '1.1.0',
        ),
        array(
            'name'               => esc_html__( 'Olam Multiple Images', 'olam' ),
            'slug'               => 'olam-multiple-images',
            'source'             => esc_url( get_template_directory_uri() . '/admin/plugins/olam-multiple-images.zip' ),
            'required'           => false,
            'version'            => '1.2',
        ),
        array(
            'name'               => esc_html__( 'Layero - EDD Related Downloads & Quick Contact', 'olam' ),
            'slug'               => 'layero-edd-related-downloads',
            'source'             => esc_url( get_template_directory_uri() . '/admin/plugins/layero-edd-related-downloads.zip' ),
            'required'           => true,
            'version'            => '1.3',
        ),
        array(
            'name'               => esc_html__( 'Unyson', 'olam' ),
            'slug'               => 'unyson',
            'source'             => esc_url( get_template_directory_uri() . '/admin/plugins/unyson.zip' ),
            'required'           => false,
            'version'            => '2.7.28',
        ),
        array(
            'name'     => esc_html__( 'Elementor', 'olam' ),
            'slug'     => 'elementor',
            'required' => false,
        ),
        array(
            'name'     => 'Nextend Social Login',
            'slug'     => 'nextend-facebook-connect',
            'required' => false,
        ),
        array(
            'name'               => esc_html__( 'Easy Digital Downloads', 'olam' ),
            'slug'               => 'easy-digital-downloads',
            'required'           => false,
        ),
    );

    // Only add these plugins if Elementor is active
    if ( class_exists( 'Elementor\Plugin' ) ) {
        $plugins = array_merge( $plugins, array(
            array(
                'name'     => esc_html__( 'Olam Widgets', 'olam' ),
                'slug'     => 'olam-widgets',
                'source'   => esc_url( get_template_directory_uri() . '/admin/plugins/olam-widgets.zip' ),
                'required' => false,
                'version'  => '1.1.0',
            ),
            array(
                'name'     => esc_html__( 'Olam Theme Widgets', 'olam' ),
                'slug'     => 'olam-theme-widgets',
                'source'   => esc_url( get_template_directory_uri() . '/admin/plugins/olam-theme-widgets.zip' ),
                'required' => true,
                'version'  => '1.0.0',
            ),
            array(
                'name'     => esc_html__( 'One Click Demo Import', 'olam' ),
                'slug'     => 'one-click-demo-import',
                'required' => false,
            ),
        ) );
    }

    $config = array(
        'id'           => 'olam',
        'default_path' => '',
        'menu'         => 'tgmpa-install-plugins',
        'parent_slug'  => 'themes.php',
        'capability'   => 'edit_theme_options',
        'has_notices'  => true,
        'dismissable'  => true,
        'dismiss_msg'  => '',
        'is_automatic' => false,
        'message'      => '',
    );

    tgmpa( $plugins, $config );
}


// =========== _/\_ TGM section ends _/\_ =============






/**
 * Olam Function - Meta box CB.
 *
 * Adding a new meta box.
 */

if( ! function_exists( 'olam_meta_box_cb' ) )
{
  function olam_meta_box_cb( $post )
  {
    $values = get_post_custom( $post->ID );
    $selected = isset( $values['olam_box_select'] ) ? esc_attr( $values['olam_box_select'][0] ) : '';
    wp_nonce_field( 'olam_meta_box_nonce_value', 'olam_box_nonce' );
    ?>    
    <p>
      <label for="olam_box_select"><?php esc_html_e("Is this a featured download","olam"); ?></label>
      <select name="olam_box_select" id="olam_box_select">
        <option value="no" <?php selected( $selected, 'no' ); ?>><?php esc_html_e("No","olam"); ?></option>
        <option value="yes" <?php selected( $selected, 'yes' ); ?>><?php esc_html_e("Yes","olam"); ?></option>
      </select>
    </p>
    <?php    
  }
}


add_action( 'save_post', 'olam_meta_box_save' );


/**
 * Olam Function - Save meta box.
 *
 * Saving the meta box values.
 */

if( ! function_exists( 'olam_meta_box_save' ) )
{
  function olam_meta_box_save( $post_id )
  {
    // Bail if we're doing an auto save
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){ return; }

    // if our nonce isn't there, or we can't verify it, bail
    if( !isset( $_POST['olam_box_nonce'] ) || !wp_verify_nonce( $_POST['olam_box_nonce'], 'olam_meta_box_nonce_value' ) ) { return; }
    
    // if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post',$post_id ) ){ return;  }

    if( isset( $_POST['olam_box_select'] ) ){
      update_post_meta( $post_id, 'olam_box_select', esc_attr( $_POST['olam_box_select'] ) );
    }

  }
}


/**
 * Olam Function - Retina Logo.
 *
 * Olam retina logo implementation.
 */

if( ! function_exists( 'olam_retina_logo' ) )
{
  function olam_retina_logo()
  {
   $olamOptions=of_get_options();
   if( isset($olamOptions['olam_theme_retina_logo']) && (strlen($olamOptions['olam_theme_retina_logo'])>0) ){
    echo '<script>'."\n";
    echo '//<![CDATA['."\n";
    echo 'jQuery(window).load(function(){'."\n";
    echo 'var retina = window.devicePixelRatio > 1 ? true : false;';
    echo 'if( retina ){';

    if( $olamOptions['olam_theme_retina_logo'] ){
      echo 'var retinaEl = jQuery(".logo img.site-logo");';
      echo 'var retinaLogoW = retinaEl.width();';
      echo 'var retinaLogoH = retinaEl.height();';
      echo 'retinaEl';
      echo '.attr( "src", "'. esc_js(esc_url($olamOptions['olam_theme_retina_logo'])) .'" )';
      echo '.width( retinaLogoW )';
      echo '.height( retinaLogoH );';
    }                
    echo '}';
    echo '});'."\n";
    echo '//]]>'."\n";
    echo '</script>'."\n";
  }

}
}
add_action('wp_head', 'olam_retina_logo');

// Fixing the edd schema
add_filter( 'edd_add_schema_microdata', '__return_false' );



/**
 * Olam Function - Olam Excerpt
 *
 * More tag to excerpt.
 */

if( ! function_exists( 'olam_new_excerpt_more' ) )
{
  function olam_new_excerpt_more($more) {
   global $post;
   return '... <a class="moretag" href="'. get_permalink($post->ID) . '"><span class="space">&nbsp;&nbsp;</span>&nbsp;'.esc_html__("read more","olam").'&nbsp;</a>';
 }
}
add_filter('excerpt_more', 'olam_new_excerpt_more');

add_filter('edd_cart_item','olam_edd_cart_item',10, 2);

/**
 * Olam Function - Olam Edd Cart Item
 *
 * Adding image to edd cart.
 */

if( ! function_exists( 'olam_edd_cart_item' ) )
{
  function olam_edd_cart_item($item,$id){

    $featImage=null;
    $theDownloadImage=get_post_meta($id,'download_item_thumbnail_id'); 
    if(is_array($theDownloadImage) && (count($theDownloadImage)>0) ){
      $thumbID=$theDownloadImage[0];
      $featImage=wp_get_attachment_image_src($thumbID,'olam-product-thumb-small');
      $featImage=$featImage[0];
    }
    else{
      $thumbID=get_post_thumbnail_id($id);
      $featImage=wp_get_attachment_image_src($thumbID,'olam-product-thumb-small');
      $featImage=$featImage[0];
    }

    if(isset($featImage)){
      $item = str_replace( '{item_image_url}', $featImage, $item );
    }
    return $item;
  }

}

add_filter('edd_empty_cart_message','olam_modify_empty_cart_message');

/**
 * Olam Function - Edd Empty Cart Message modify
 *
 *  Modifying the empty cart message style
 */


if( ! function_exists( 'olam_modify_empty_cart_message' ) )
{
  function olam_modify_empty_cart_message($message){

	$booking_url = get_home_url();
    $message='<div class="empty-cart text-center"><div class="cart-icon"><i class="demo-icon icon-cart"></i></div><div><span class="edd_empty_cart">' . esc_html__( 'Your cart is empty.', 'olam' ) . '</span>
<h5 class="primary"><a href="'.$booking_url.'">'.esc_html__('Please add a product','olam').'</a></h5></div></div>';
    return $message;
  }
}

/**
 * Olam Function - Custom excerpt length
 *
 *  Modifying the excerpt length
 */

if( ! function_exists( 'olam_custom_excerpt_length' ) )
{
  function olam_custom_excerpt_length( $length ) {
    return 150;
  }
}

add_filter( 'excerpt_length', 'olam_custom_excerpt_length', 999 );




//Add sanitization for WordPress posts
add_filter( 'pre_user_description', 'wp_filter_post_kses');

/**
 * Olam Function - Replace Site Url
 *
 *  Replacing the theme options siteurl with actual protocols.
 */

function olam_replace_site_url($url){
  if (is_string($url)) {
    $data = str_replace(
      array(
        '[site_url]', 
        '[site_url_secure]',
        ),
      array(
        site_url('', 'http'),
        site_url('', 'https'),
        ),
      $url
      );
  }
  return $data;
}



/**
 * Olam Function - Price Filter
 *
 *  Removing the id(to fix duplicate id issue) from price displayed.
 */

add_filter("edd_download_price_after_html","olam_edd_price_filter",10, 3);

function olam_edd_price_filter($pricehtml,$id,$price){

  $newpricehtml='<span class="edd_price" >'.$price.'</span>';
  return  $newpricehtml;
}

/**
 * Olam Function - Check for comments/pingbacks
 *
 *  Removing the id(to fix duplicate id issue) from price displayed.
 */

function olam_post_has( $type, $post_id ) {

  $comments = get_comments('status=approve&type=' . $type . '&post_id=' . $post_id );
  $comments = separate_comments( $comments );
  return 0 < count( $comments[ $type ] );

}


/**
 * Olam Function - Validate gravatar
 *
 *  Validating gravatar from email.
 */

function olam_validate_gravatar($email) {
  //print_r($email); die;
  // Craft a potential url and test its headers
  $hash = md5(strtolower(trim($email)));
  $uri = 'https://www.gravatar.com/avatar/' . $hash . '?d=404';
  $headers = @get_headers($uri);
  if (!preg_match("|200|", $headers[0])) {
    $has_valid_avatar = FALSE;
  } else {
    $has_valid_avatar = TRUE;
  }
  return $has_valid_avatar;
}

/**
 * Olam Function - Get terms dropdown
 *
 *  Adding the download category filter.
 */


function olam_get_terms_dropdown() {
    $values = array(
      'show_option_all' => esc_html__('All','olam'),
      'orderby' => 'name',
      'order' => 'ASC',
      'echo' => 1,
      'hide_empty' => 1,
      'show_count' => 1,
      'selected' => $kat = get_query_var( 'download_cat' ),
      'name' => 'download_cat',
      'hierarchical'  => 1,
      'id' => '',
      'value_field' => 'name',
      'class' => 'download_cat_filter',
      'taxonomy' => 'download_category'
     );
    $categories = wp_dropdown_categories($values);
}


/**
 * Olam Function - posts_where Filter edit for search (custom post type = download)
 *
 */

function olam_search_where($where){
  global $wpdb;

  if( is_search() ){

    $where .= "OR (t.name LIKE '%".get_search_query()."%' AND {$wpdb->posts}.post_status = 'publish' )";
    return $where;

  }
}

function olam_search_join($join){
  global $wpdb;

  if( is_search()){
    $join .= "LEFT JOIN {$wpdb->term_relationships} tr ON {$wpdb->posts}.ID = tr.object_id INNER JOIN {$wpdb->term_taxonomy} tt ON tt.term_taxonomy_id=tr.term_taxonomy_id INNER JOIN {$wpdb->terms} t ON t.term_id = tt.term_id";
    return $join;
  }
}

function olam_search_groupby($groupby){
  global $wpdb;

  // we need to group on post ID
  $groupby_id = "{$wpdb->posts}.ID";
  if(!is_search() || strpos($groupby, $groupby_id) !== false) return $groupby;

  // groupby was empty, use ours
  if(!strlen(trim($groupby))) return $groupby_id;

  // wasn't empty, append ours
  return $groupby.", ".$groupby_id;
}

 // add_filter('posts_where','olam_search_where');
  //add_filter('posts_join', 'olam_search_join');
  //add_filter('posts_groupby', 'olam_search_groupby');


/**
 * Do not include php tag
 */ 
add_filter( 'posts_join', 'olam_custom_posts_join', 10, 2 );
/**
 * Callback for WordPress 'posts_join' filter.'
 * 
 * @global $wpdb
 * @see https://codex.wordpress.org/Class_Reference/wpdb
 * 
 * @link https://codex.wordpress.org/Plugin_API/Filter_Reference/posts_join
 * 
 * @param  string   $join     The sql JOIN clause.
 * @param  WP_Query $wp_query The current WP_Query instance.
 * @return string   $join     The sql JOIN clause.
 */
function olam_custom_posts_join( $join, $query ) {

  global $wpdb;
    //* if main query and search...
  if ( is_main_query() && is_search() ) {

        //* join term_relationships, term_taxonomy, and terms into the current SQL where clause
    $join .= "
    LEFT JOIN 
    ( 
    {$wpdb->term_relationships}
    INNER JOIN 
    {$wpdb->term_taxonomy} ON {$wpdb->term_taxonomy}.term_taxonomy_id = {$wpdb->term_relationships}.term_taxonomy_id 
    INNER JOIN 
    {$wpdb->terms} ON {$wpdb->terms}.term_id = {$wpdb->term_taxonomy}.term_id 
    ) 
    ON {$wpdb->posts}.ID = {$wpdb->term_relationships}.object_id ";

  }
  return $join;

}




/**
 * Do not include php tags
 */ 
add_filter( 'posts_where', 'olam_custom_posts_where', 10, 2 );
/**
 * Callback for WordPress 'posts_where' filter.
 * 
 * Modify the where clause to include searches against a WordPress taxonomy.
 * 
 * @see https://codex.wordpress.org/Plugin_API/Filter_Reference/posts_where
 * 
 * @param  string   $where The where clause.
 * @param  WP_Query $query The current WP_Query.
 * @return string          The where clause.
 */ 
function olam_custom_posts_where( $where, $query ) {

  global $wpdb;
  if ( is_main_query() && is_search() ) {

        //* get additional where clause for the user
    $user_where = olam_get_user_posts_where();

    $where .= " OR (
    {$wpdb->term_taxonomy}.taxonomy IN( 'category', 'post_tag' ) 
    AND
    {$wpdb->terms}.name LIKE '%" . esc_sql( get_query_var( 's' ) ) . "%'
    {$user_where}
    )";

  }
  return $where;

}
/**
 * Get a where clause dependent on the current user's status.
 *
 * @global $wpdb
 * @see https://codex.wordpress.org/Class_Reference/wpdb
 * 
 * @uses get_current_user_id()
 * @see http://codex.wordpress.org/Function_Reference/get_current_user_id
 * 
 * @return string The user where clause.
 */
function olam_get_user_posts_where() {

  global $wpdb;
  $user_id = get_current_user_id();
  $sql     = '';
  $status  = array( "'publish'" );
  if ( 0 !== $user_id ) {

    $status[] = "'private'";

    $sql .= " AND {$wpdb->posts}.post_author = " . absint( $user_id );

  }
  $sql .= " AND {$wpdb->posts}.post_status IN( " . implode( ',', $status ) . " ) ";

  return $sql;

}


/**
 * Do not include php tags
 */ 
add_filter( 'posts_groupby', 'olam_custom_posts_groupby', 10, 2 );
/**
 * Callback for WordPress 'posts_groupby' filter.
 * 
 * Set the GROUP BY clause to post IDs.
 * 
 * @global $wpdb
 * @see https://codex.wordpress.org/Class_Reference/wpdb
 * 
 * @param  string   $groupby The GROUPBY caluse.
 * @param  WP_Query $query   The current WP_Query object.
 * @return string            The GROUPBY clause.
 */ 

function olam_custom_posts_groupby( $groupby, $query ) {

  global $wpdb;
    //* if is main query and a search...
  if ( is_main_query() && is_search() ) {
    $groupby = "{$wpdb->posts}.ID";
  }
  return $groupby;
}



// ===========  Theme Demo data installation

/**
 * @param FW_Ext_Backups_Demo[] $demos
 * @return FW_Ext_Backups_Demo[]
 */
function olam_filter_theme_fw_ext_backups_demos($demos) {
    $demos_array = array(
        'olam_demo_1_2' => array(
            'title'        => esc_html__('demo1,2-Main', 'olam'),
            'screenshot'   => 'https://themes.layero.com/olamwp/demo-data/demo12-main/screenshot.png',
            'preview_link' => 'https://themes.layero.com/olamwp/',
        ),
        'olam_demo_3' => array(
            'title'        => esc_html__('demo3-Services', 'olam'),
            'screenshot'   => 'https://themes.layero.com/olamwp/demo-data/demo3-services/screenshot.png',
            'preview_link' => 'https://themes.layero.com/olamwp3/',
        ),
        'olam_demo_4' => array(
            'title'        => esc_html__('demo4-Booking', 'olam'),
            'screenshot'   => 'https://themes.layero.com/olamwp/demo-data/demo4-booking/screenshot.png',
            'preview_link' => 'https://themes.layero.com/olamwp4/',
        ),
    );

    $download_url = 'https://themes.layero.com/olamwp/demo-data/index.php';

    foreach ($demos_array as $id => $data) {
        $demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
            'url' => $download_url,
            'file_id' => $id,
        ));
        $demo->set_title($data['title']);
        $demo->set_screenshot($data['screenshot']);
        $demo->set_preview_link($data['preview_link']);

        $demos[ $demo->get_id() ] = $demo;

        unset($demo);
    }

    return $demos;
}
add_filter('fw:ext:backups-demo:demos', 'olam_filter_theme_fw_ext_backups_demos');


// Function to remove version numbers
function sdt_remove_ver_css_js( $src ) {
  if ( strpos( $src, 'ver=' ) )
    $src = remove_query_arg( 'ver', $src );
  return $src;
}


// display custom admin notice
function st_custom_admin_notice() {
  $st_th_info = wp_get_theme(); 
  $currentversion = str_replace('.','',(esc_html( $st_th_info->get('Version') )));
  $isitdismissed = 'st_notice_dismissed'.$currentversion;
  if ( !get_user_meta( get_current_user_id() , $isitdismissed ) ) { ?>
  <div class="notice notice-success is-dismissible st_notice" data-dismissible="disable-done-notice-forever">
    <div>
      <p> 
      <?php _e('Thank you for updating to the latest version of ','olam'); ?>
      <?php echo esc_html( $st_th_info->get('Name') );?> - 
      <?php echo esc_html( $st_th_info->get('Version') );
       ?>
      <?php _e('theme. Check out the best ', 'olam'); ?>
      <a href="<?php echo esc_url( 'https://layero.com/eddaddons?utm_source=ThemeAdmin&utm_medium=UpdateMsg&utm_campaign=Olam');?>" target="_blank" aria-label="Dismiss this message">
        <strong><?php _e('EDD Addons','olam');?></strong>
      </a>
      <?php _e('and extend your site features!', 'olam'); ?>
      <a href="?st-notice-dismissed<?php echo esc_attr($currentversion); ?>">Dismiss this message</a>
      </p>
    </div>
    
  </div>
  
<?php
  }
 }
add_action('admin_notices', 'st_custom_admin_notice');

function st_notice_dismissed() {
  $st_th_info = wp_get_theme(); 
  $currentversion = str_replace('.','',(esc_html( $st_th_info->get('Version') )));
  $dismissurl = 'st-notice-dismissed'.$currentversion;
  $isitdismissed = 'st_notice_dismissed'.$currentversion;
    $user_id = get_current_user_id();
    if ( isset( $_GET[$dismissurl] ) )
        add_user_meta( $user_id, $isitdismissed, 'true', true );
}
add_action( 'admin_init', 'st_notice_dismissed' );


// Hide Brizy page builder upsell admin notice and WC template notices
add_action('admin_head', 'hide_brizy_admin_notice');
function hide_brizy_admin_notice() {
  echo '<style>
    .fw-brz-dismiss, #fw-ext-brizy.fw-extensions-list-item, .updated.woocommerce-message {
      display:none!important;
    }
    .appearance_page_optionsframework #header .notice {display:none!important;}
  </style>';
}

// header option customize section.
    
add_action( 'after_setup_theme','remove_twentyeleven_options', 100 );
function remove_twentyeleven_options() {    
    remove_theme_support('custom-header');
    remove_action('admin_menu', 'twentyeleven_theme_options_add_page');    
}

// Add the checkbox field to the General Settings page
function add_custom_checkbox_field() {
    // Get the current value of the checkbox
    $checked = get_option('custom_checkbox_field', '0');
    $checked = ( $checked === '1' ) ? 'checked' : '';
    ?>
    <table class="form-table">
        <tr>
            <th scope="row">
                <label for="custom_checkbox_field"><?php esc_html_e( 'Phone Number Field', 'text-domain' ); ?></label>
            </th>
            <td>
                <label for="custom_checkbox_field">
                    <input type="checkbox" id="custom_checkbox_field" name="custom_checkbox_field" value="1" <?php echo esc_attr( $checked ); ?>>
                    <?php esc_html_e( 'Enable Phone Number Field', 'text-domain' ); ?>
                </label>
            </td>
        </tr>
    </table>
    <?php
}

add_action( 'admin_init', 'register_custom_checkbox_field' );

// Register the custom checkbox field
function register_custom_checkbox_field() {
    register_setting( 'general', 'custom_checkbox_field', 'sanitize_custom_checkbox_field' );
    add_settings_field( 'custom_checkbox_field', 'Add Phone Number Field On Register', 'add_custom_checkbox_field', 'general' );
}

// Sanitize and validate the checkbox field value
function sanitize_custom_checkbox_field( $input ) {
    $input = ( isset( $input ) && $input === '1' ) ? '1' : '0';
    return $input;
}

// Add phone number field to user edit page in admin dashboard
function add_phone_number_field($user)
{
    ?>
    <h3><?php _e('Additional Contact Information', 'textdomain'); ?></h3>

    <table class="form-table">
        <tr>
            <th><label for="phone_number"><?php _e('Phone Number', 'textdomain'); ?></label></th>
            <td>
                <input type="text" name="phone_number" id="phone_number" value="<?php echo esc_attr(get_user_meta($user->ID, 'phone_number', true)); ?>" class="regular-text" />
            </td>
        </tr>
    </table>
    <?php
}
add_action('edit_user_profile', 'add_phone_number_field');
add_action('show_user_profile', 'add_phone_number_field');

// Save phone number field data
function save_phone_number_field($user_id)
{
    if (!current_user_can('edit_user', $user_id)) {
        return false;
    }

    if (!empty($_POST['phone_number'])) {
        $phone_number = sanitize_text_field($_POST['phone_number']);
        update_user_meta($user_id, 'phone_number', $phone_number);
    } else {
        delete_user_meta($user_id, 'phone_number');
    }
}
add_action('personal_options_update', 'save_phone_number_field');
add_action('edit_user_profile_update', 'save_phone_number_field');




/* edit profile update phone number code start here */
function custom_enqueue_scripts() {
  wp_enqueue_script( 'jquery' ); // Enqueue jQuery library

  // Add custom jQuery code inline
  wp_add_inline_script( 'jquery', '
    jQuery(document).ready(function($) {
      $("#edd_profile_editor_submit").on("click", function(e) {
        
        var phoneNumber = $("#edd_phone_number").val();

        // Perform any additional validation or processing if needed

        // Update the phone number field via AJAX
        $.ajax({
          url: ajaxurl,
          type: "POST",
          data: {
            action: "update_phone_number",
            phone_number: phoneNumber
          },
          success: function(response) {
            console.log("Phone number updated successfully");
          },
          error: function(xhr, status, error) {
            console.log("Error updating phone number: " + error);
          }
        });
      });
    });
  ' );
}
add_action( 'wp_enqueue_scripts', 'custom_enqueue_scripts' );


add_action( 'wp_ajax_update_phone_number', 'custom_update_phone_number' );
add_action( 'wp_ajax_nopriv_update_phone_number', 'custom_update_phone_number' );

function custom_update_phone_number() {
  if ( isset( $_POST['phone_number'] ) ) {
    $user_id = get_current_user_id();
    $phone_number = sanitize_text_field( $_POST['phone_number'] );

    // Update the phone number field
    update_user_meta( $user_id, 'phone_number', $phone_number );

    wp_send_json_success(); // Return a success response
  } else {
    wp_send_json_error(); // Return an error response
  }
}
/* edit profile update phone number code end here */


//Comment option not showing on display option in product edit page

function enable_comments_for_download() {
    add_post_type_support('download', 'comments');
}
add_action('init', 'enable_comments_for_download');


/* Upload Image folder demo code start here */

function olam_activate() {
    // Get the upload directory
    $upload_dir = wp_upload_dir();
    // Define the source and destination paths for each folder
    $folders = [
        '2015/09' => $upload_dir['basedir'] . '/2015/09',
        '2015/10' => $upload_dir['basedir'] . '/2015/10',
        '2015/12' => $upload_dir['basedir'] . '/2015/12'
    ];
 
    foreach ($folders as $relative_path => $destination_path) {
        // Define the source path
        $source_path = get_template_directory() . '/import-images/' . $relative_path;
 
        // Check if the custom folder already exists in the uploads directory
        if (!file_exists($destination_path)) {
            // Recursively copy the custom folder to the uploads directory
            olam_recursive_copy($source_path, $destination_path);
        }
    }
}

// Function to recursively copy files and folders
function olam_recursive_copy($source, $destination) {
    $dir = opendir($source);
    wp_mkdir_p($destination); // Use wp_mkdir_p() instead of @mkdir()
 
    while (false !== ($file = readdir($dir))) {
        if (($file != '.') && ($file != '..')) {
            if (is_dir($source . '/' . $file)) {
                olam_recursive_copy($source . '/' . $file, $destination . '/' . $file);
            } else {
                copy($source . '/' . $file, $destination . '/' . $file);
            }
        }
    }
    closedir($dir);
}

// Hook into the theme activation
add_action('after_switch_theme', 'olam_activate');


/* Upload Image folder demo code end here */




// Ensure the function to check active plugins is available
if ( ! function_exists( 'is_plugin_active' ) ) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

// Check if the Elementor plugin is active by checking for a specific class it uses
if ( class_exists( 'Elementor\Plugin' ) ) {
    // Function to import demo files
    function ocdi_import_files() {
        return array(
            array(
                'import_file_name'           => 'Demo Import',
                'local_import_file'          => trailingslashit( get_template_directory() ) . 'elementor-demo-pages/olam.demo.xml',
                'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'elementor-demo-pages/olam-export.dat',
                'local_import_widget_file'   => trailingslashit( get_template_directory() ) . 'elementor-demo-pages/olam.chirpnuat.com-widgets.wie',
                'import_notice'              => __( 'Importing demo content...', 'olam' ),
            ),
        );
    }
    add_filter( 'ocdi/import_files', 'ocdi_import_files' );

    // Function to set up after import
    function ocdi_after_import_setup() {
        // Assign menus to their locations
        $main_menu = get_term_by( 'name', 'All Pages', 'nav_menu' );

        // Check if the menu exists
        if ( $main_menu ) {
            // Set the menu location
            set_theme_mod( 'nav_menu_locations', array(
                'header-top-menu' => $main_menu->term_id, 
            ));
        }

        // Assign front page and posts page
        $front_page_id = get_page_by_title( 'New Olam Home page' );
        $blog_page_id  = get_page_by_title( 'Blog' );

        if ( $front_page_id && $blog_page_id ) {
            update_option( 'show_on_front', 'page' );
            update_option( 'page_on_front', $front_page_id->ID );
            update_option( 'page_for_posts', $blog_page_id->ID );
        }
    }
    add_action( 'ocdi/after_import', 'ocdi_after_import_setup' );
}



function theme_enqueue_styles() {
    // Enqueue theme stylesheet
    wp_enqueue_style('theme-style', get_stylesheet_uri());

    // Enqueue Font Awesome CSS from local path
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.min.css', array(), '4.7.0', 'all');
}
add_action('wp_enqueue_scripts', 'theme_enqueue_styles');
